@@ -1,6 +1,8 @@
 package URI::Fetch;
-use strict;
+$URI::Fetch::VERSION = '0.10';
 use 5.008_001;
+use strict;
+use warnings;
 
 use base qw( Class::ErrorHandler );
 
@@ -9,8 +11,6 @@ use Carp qw( croak );
 use URI;
 use URI::Fetch::Response;
 
-our $VERSION = '0.09';
-
 our $HAS_ZLIB;
 BEGIN {
     $HAS_ZLIB = eval "use Compress::Zlib (); 1;";
@@ -134,7 +134,7 @@ sub fetch {
     if ($cache &&
         ($p_cache_grep ? $p_cache_grep->($fetch) : 1)) {
 
-        $cache->set($fetch->uri, $freeze->({
+        $cache->set($uri, $freeze->({
             ETag         => $fetch->etag,
             LastModified => $fetch->last_modified,
             Content      => $fetch->content,
@@ -159,6 +159,7 @@ URI::Fetch - Smart URI fetching/caching
     ## Simple fetch.
     my $res = URI::Fetch->fetch('http://example.com/atom.xml')
         or die URI::Fetch->errstr;
+    do_something($res->content) if $res->is_success;
 
     ## Fetch using specified ETag and Last-Modified headers.
     $res = URI::Fetch->fetch('http://example.com/atom.xml',
@@ -232,6 +233,16 @@ so you should stop trying to fetch it.
 
 =back
 
+=head2 Change from 0.09
+
+If you make a request using a cache and get back a 304 response code
+(Not Modified), then if the content was returned from the cache,
+then C<is_success()> will return true, and C<$response-E<gt>content>
+will contain the cached content.
+
+I think this is the right behaviour, given the philosophy of C<URI::Fetch>,
+but please let me (NEILB) know if you disagree.
+
 =head1 USAGE
 
 =head2 URI::Fetch->fetch($uri, %param)
@@ -353,6 +364,10 @@ using the C<errstr> method on the class.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/URI-Fetch>
+
 =head1 LICENSE
 
 I<URI::Fetch> is free software; you may redistribute it and/or modify it
